# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""MRIQC resources."""
from .config import Template, IndividualTemplate, GroupTemplate

__all__ = ["Template", "IndividualTemplate", "GroupTemplate"]
